@@ -15,8 +15,9 @@ except ImportError:
 
 DEBUG = False
 
-BEGIN_PATTERN = re.compile(r"""begin (\w+);""", re.IGNORECASE)
-END_PATTERN = re.compile(r"""end;""", re.IGNORECASE)
+BEGIN_PATTERN = re.compile(r"""begin (\w+)(\s*|\[.*\]);""", 
+re.IGNORECASE)
+END_PATTERN = re.compile(r"""end\s*;""", re.IGNORECASE)
 NTAX_PATTERN = re.compile(r"""ntax=(\d+)""", re.IGNORECASE)
 NCHAR_PATTERN = re.compile(r"""nchar=(\d+)""", re.IGNORECASE)
 COMMENT_PATTERN = re.compile(r"""(\[.*?\])""")
@@ -471,31 +472,37 @@ class DataHandler(GenericHandler):
         :raises NexusFormatException: If data matrix contains incomplete
             multistate values
         """
-        out = []
-        multistate = False
-        sites = [site for site in sites]
-        while len(sites) > 0:
-            site = sites.pop(0)
-            if site == ' ':
-                continue
-            elif site == '(':
-                # read-ahead
-                site = ''  # discard open bracket
-                multistate = True
-                while multistate:
-                    nextchar = sites.pop(0)
-                    if nextchar == ')':
-                        multistate = False
-                    else:
-                        site += nextchar
-            out.append(site)
+        sites = [s for s in sites if s != ' ']
+        if '(' not in sites:
+            import sys; sys.stdout.write("FAST"); sys.stdout.flush()
+            return sites
+        else:
+            import sys; sys.stdout.write("SLOW"); sys.stdout.flush()
+            multistate = False
+            out = []
+            # Slow reader for multistate
+            while len(sites) > 0:
+                site = sites.pop(0)
+                if site == ',':
+                    continue
+                elif site == '(':
+                    # read-ahead
+                    site = ''  # discard open bracket
+                    multistate = True
+                    while multistate:
+                        nextchar = sites.pop(0)
+                        if nextchar == ')':
+                            multistate = False
+                        else:
+                            site += nextchar
+                out.append(site)
             
-        # check we're not in hanging multistate chunk
-        if multistate:
-            raise NexusFormatException(
-                "Data Matrix contains incomplete multistate values"
-            )
-        return out
+            # check we're not in hanging multistate chunk
+            if multistate:
+                raise NexusFormatException(
+                    "Data Matrix contains incomplete multistate values"
+                )
+            return out
 
     def add_taxon(self, taxon, site_values=None):
         """
@@ -744,7 +751,7 @@ class NexusReader(object):
             # check if we're in a block and initialise
             found = BEGIN_PATTERN.findall(line)
             if found:
-                block = found[0].lower()
+                block = found[0][0].lower()
                 if block in store:
                     raise NexusFormatException("Duplicate Block %s" % block)
                 store[block] = []
