@@ -1,5 +1,5 @@
 from nexus.writer import NexusWriter
-from nexus.tools import check_for_valid_NexusReader
+from nexus.tools.check_for_valid_NexusReader import check_for_valid_NexusReader
 
 def multistatise(nexus_obj, charlabel=None):
     """
